@@ -197,6 +197,20 @@ class OnlineDevice(DeviceBase):
         """Check if the device should be ignored."""
         return self._proxy.property.DevicePresentationHide
 
+    @property
+    def device_id(self):
+        """
+        Return a unique and persistent identifier for the device.
+
+        This is the basename (last path component) of the symlink in
+        `/dev/disk/by-id/`.
+        """
+        for filename in self._proxy.property.DeviceFileById:
+            parts = filename.split('/')
+            if parts[-2] == 'by-id':
+                return parts[-1]
+        return ''
+
     @property
     def id_type(self):
         """"
